@@ -9,7 +9,7 @@
 #' @param x_axis_label Label for the x axis.
 #' @param plot_palette Character vector of hex codes specifying the colors to use on the plot.
 #' @param plot_palette_generator Palette from the viridis package used in case plot_palette is unspecified or insufficient for the number of colors required.
-#' @param static If TRUE, the output will be static ggplot chart instead of an interactive ggplotly chart. Default is FALSE.
+#' @param static If TRUE (or if the dataset is over 10,000 rows), the output will be static ggplot chart instead of an interactive ggplotly chart. Default is FALSE.
 #'
 #' @export
 #' @return A plotly-ized version of a ggplot density plot.
@@ -34,6 +34,17 @@ make_density <- function(dt,
                          plot_palette_generator = 'plasma',
                          static = FALSE){
 
+  # check that the specified columns are present in the data provided
+  dt_cols <- c(value, groups)
+  if(any(!(dt_cols %in% colnames(dt)))){
+    stop(paste(setdiff(dt_cols, colnames(dt)), collapse = ', '), ' not found on dt.')
+  }
+
+  # coerce groups and split_groups_by to characters
+  if(!is.null(groups)){
+    dt <- chronicle::set_classes(dt, character = groups)
+  }
+
   # check how many colors are needed for plotting
   plot_palette_length <- ifelse(test = is.null(groups),
                                 yes = 1,
@@ -61,6 +72,9 @@ make_density <- function(dt,
                                    'magma' = viridis::magma,
                                    'plasma' = viridis::plasma,
                                    'viridis' = viridis::viridis,
+                                   'mako' = viridis::mako,
+                                   'rocket' = viridis::rocket,
+                                   'turbo' = viridis::turbo,
                                    viridis::plasma)
 
   #if not provided, use palette from viridis::plasma
@@ -102,7 +116,8 @@ make_density <- function(dt,
       ggplot2::theme(legend.position = 'none',
                      axis.title.x = ggplot2::element_blank(),
                      axis.text.x = ggplot2::element_blank(),
-                     axis.ticks.x = ggplot2::element_blank())
+                     axis.ticks.x = ggplot2::element_blank(),
+                     strip.text.x = ggplot2::element_blank())
   }
 
   # axes
@@ -116,7 +131,8 @@ make_density <- function(dt,
                                              scales = scales)
   }
 
-  if(!as.logical(static)){
+  # only convert to plotly if the dataset is under 10,000 rows
+  if(!as.logical(static) & nrow(dt) <= 10000){
     density <- plotly::ggplotly(density,  tooltip = c('x', 'y', if(groups != 'groups'){'fill'}))
   }
   return(density)
@@ -174,21 +190,22 @@ add_density <- function(report = '',
     stop(paste(setdiff(dt_cols, colnames(dt)), collapse = ', '), ' not found on dt.')
   }
 
-  params <- list(value = value,
+  params <- list(dt = ifelse(test = is.character(dt),
+                             yes = dt,
+                             no = deparse(substitute(dt))),
+                 value = value,
                  groups = groups,
                  faceted = faceted,
                  scales = scales,
                  ggtheme = ggtheme,
                  x_axis_label = x_axis_label,
-                 plot_palette = plot_palette,
-                 plot_palette_generator = plot_palette_generator) %>%
+                 plot_palette = ifelse(is.null(plot_palette), 'params$plot_palette', plot_palette),
+                 plot_palette_generator = ifelse(is.null(plot_palette_generator), 'params$plot_palette_generator', plot_palette_generator),
+                 static = 'params$set_static') %>%
     purrr::discard(is.null)
 
   report <- chronicle::add_chunk(report = report,
-                                 dt_expr = ifelse(test = is.character(dt),
-                                                  yes = dt,
-                                                  no = deparse(substitute(dt))),
-                                 fun = make_density,
+                                 fun = chronicle::make_density,
                                  params = params,
                                  chunk_title = density_title,
                                  title_level = title_level,
@@ -196,7 +213,8 @@ add_density <- function(report = '',
                                  message = message,
                                  warning = warning,
                                  fig_width = fig_width,
-                                 fig_height = fig_height)
+                                 fig_height = fig_height,
+                                 guess_title = TRUE)
   return(report)
 }
 
